@@ -128,7 +128,7 @@ def label_cells_by_cluster(fov, all_data, label_map, fov_col=settings.FOV_ID,
     return relabeled_img_array
 
 
-def generate_cell_cluster_mask(fov, base_dir, seg_dir, cell_data_name,
+def generate_cell_cluster_mask(fov, base_dir, seg_dir, cell_data,
                                cell_cluster_col='cell_meta_cluster',
                                seg_suffix='_whole_cell.tiff'):
     """For a fov, create a mask labeling each cell with their SOM or meta cluster label
@@ -140,8 +140,8 @@ def generate_cell_cluster_mask(fov, base_dir, seg_dir, cell_data_name,
             The path to the data directory
         seg_dir (str):
             The path to the segmentation data
-        cell_data_name (str):
-            The path to the cell data with both cell SOM and meta cluster assignments
+        cell_data (pandas.DataFrame):
+            The cell data with both cell SOM and meta cluster assignments
         cell_cluster_col (str):
             Whether to assign SOM or meta clusters.
             Needs to be `'cell_som_cluster'` or `'cell_meta_cluster'`
@@ -154,8 +154,7 @@ def generate_cell_cluster_mask(fov, base_dir, seg_dir, cell_data_name,
     """
 
     # path checking
-    cell_data_path = os.path.join(os.path.join(base_dir, cell_data_name))
-    io_utils.validate_paths([seg_dir, cell_data_path])
+    io_utils.validate_paths([seg_dir])
 
     # verify the cluster_col provided is valid
     misc_utils.verify_in_list(
@@ -163,11 +162,8 @@ def generate_cell_cluster_mask(fov, base_dir, seg_dir, cell_data_name,
         valid_cluster_cols=['cell_som_cluster', 'cell_meta_cluster']
     )
 
-    # load the consensus data in
-    cell_consensus_data = feather.read_dataframe(os.path.join(base_dir, cell_data_name))
-
     # ensure the cluster col will be displayed as an integer and not a float
-    cell_consensus_data[cell_cluster_col] = cell_consensus_data[cell_cluster_col].astype(int)
+    cell_data[cell_cluster_col] = cell_data[cell_cluster_col].astype(int)
 
     # define the file for whole cell
     whole_cell_files = [fov + seg_suffix]
@@ -180,7 +176,7 @@ def generate_cell_cluster_mask(fov, base_dir, seg_dir, cell_data_name,
 
     # use label_cells_by_cluster to create cell masks
     img_data = label_cells_by_cluster(
-        fov, cell_consensus_data, label_map, fov_col='fov',
+        fov, cell_data, label_map, fov_col='fov',
         cell_label_column='segmentation_label', cluster_column=cell_cluster_col
     )
 
@@ -191,7 +187,7 @@ def generate_and_save_cell_cluster_masks(fovs: List[str],
                                          base_dir: Union[pathlib.Path, str],
                                          save_dir: Union[pathlib.Path, str],
                                          seg_dir: Union[pathlib.Path, str],
-                                         cell_data_name: Union[pathlib.Path, str],
+                                         cell_data: pd.DataFrame,
                                          cell_cluster_col: str = 'cell_meta_cluster',
                                          seg_suffix: str = '_whole_cell.tiff',
                                          sub_dir: str = None,
@@ -207,8 +203,8 @@ def generate_and_save_cell_cluster_masks(fovs: List[str],
             The directory to save the generated cell cluster masks.
         seg_dir (Union[pathlib.Path, str]):
             The path to the segmentation data.
-        cell_data_name (Union[pathlib.Path, str]):
-            The path to the cell data with both cell SOM and meta cluster assignments
+        cell_data (pandas.DataFrame):
+            The cell data with both cell SOM and meta cluster assignments
         cell_cluster_col (str, optional):
             Whether to assign SOM or meta clusters. Needs to be `'cell_som_cluster'` or
             `'cell_meta_cluster'`. Defaults to `'cell_meta_cluster'`.
@@ -228,7 +224,7 @@ def generate_and_save_cell_cluster_masks(fovs: List[str],
             # generate the cell mask for the FOV
             cell_mask: np.ndarray =\
                 generate_cell_cluster_mask(fov=fov, base_dir=base_dir, seg_dir=seg_dir,
-                                           cell_data_name=cell_data_name,
+                                           cell_data=cell_data,
                                            cell_cluster_col=cell_cluster_col,
                                            seg_suffix=seg_suffix)
 
@@ -425,71 +421,6 @@ def generate_and_save_neighborhood_cluster_masks(fovs: List[str],
             neigh_mask_progress.update(1)
 
 
-# TODO: Add metadata for channel name (eliminates need for fixed-order channels)
-def generate_deepcell_input(data_dir, tiff_dir, nuc_channels, mem_channels, fovs,
-                            is_mibitiff=False, img_sub_folder="TIFs", dtype="int16"):
-    """Saves nuclear and membrane channels into deepcell input format.
-    Either nuc_channels or mem_channels should be specified.
-
-    Writes summed channel images out as multitiffs (channels first).
-
-    Args:
-        data_dir (str):
-            location to save deepcell input tifs
-        tiff_dir (str):
-            directory containing folders of images, is_mibitiff determines what type
-        nuc_channels (list):
-            nuclear channels to be summed over
-        mem_channels (list):
-            membrane channels to be summed over
-        fovs (list):
-            list of folders to or MIBItiff files to load imgs from
-        is_mibitiff (bool):
-            if the images are of type MIBITiff
-        img_sub_folder (str):
-            if is_mibitiff is False, define the image subfolder for each fov
-            ignored if is_mibitiff is True
-        dtype (str/type):
-            optional specifier of image type.  Overwritten with warning for float images
-    Raises:
-        ValueError:
-            Raised if nuc_channels and mem_channels are both None or empty
-    """
-
-    # cannot have no nuclear and no membrane channels
-    if not nuc_channels and not mem_channels:
-        raise ValueError('Either nuc_channels or mem_channels should be non-empty.')
-
-    # define the channels list by combining nuc_channels and mem_channels
-    channels = (nuc_channels if nuc_channels else []) + (mem_channels if mem_channels else [])
-
-    # filter channels for None (just in case)
-    channels = [channel for channel in channels if channel is not None]
-
-    for fov in fovs:
-        # load the images in the current fov batch
-        if is_mibitiff:
-            data_xr = load_utils.load_imgs_from_mibitiff(
-                tiff_dir, mibitiff_files=[fov], channels=channels
-            )
-        else:
-            data_xr = load_utils.load_imgs_from_tree(
-                tiff_dir, img_sub_folder=img_sub_folder, fovs=[fov], channels=channels
-            )
-
-        fov_name = data_xr.fovs.values[0]
-        out = np.zeros((2, data_xr.shape[1], data_xr.shape[2]), dtype=data_xr.dtype)
-
-        # sum over channels and add to output
-        if nuc_channels:
-            out[0] = np.sum(data_xr.loc[fov_name, :, :, nuc_channels].values, axis=2)
-        if mem_channels:
-            out[1] = np.sum(data_xr.loc[fov_name, :, :, mem_channels].values, axis=2)
-
-        save_path = os.path.join(data_dir, f"{fov_name}.tiff")
-        image_utils.save_image(save_path, out)
-
-
 def split_img_stack(stack_dir, output_dir, stack_list, indices, names, channels_first=True):
     """Splits the channels in a given directory of images into separate files
 
