@@ -7,7 +7,7 @@ import pandas as pd
 import xarray as xr
 
 import ark.settings as settings
-from ark.utils import synthetic_spatial_datagen
+import synthetic_spatial_datagen
 
 TEST_MARKERS = list('ABCDEFG')
 
@@ -132,20 +132,23 @@ def _make_neighborhood_matrix():
             a sample neighborhood matrix with three different populations,
             intended to test clustering
     """
-    col_names = {0: settings.FOV_ID, 1: settings.CELL_LABEL, 2: 'feature1', 3: 'feature2'}
-    neighbor_counts = pd.DataFrame(np.zeros((200, 4)))
+    col_names = {0: settings.FOV_ID, 1: settings.CELL_LABEL, 2: settings.CELL_TYPE,
+                 3: 'feature1', 4: 'feature2'}
+    neighbor_counts = pd.DataFrame(np.zeros((200, 5)))
     neighbor_counts = neighbor_counts.rename(col_names, axis=1)
 
     neighbor_counts.iloc[0:100, 0] = "fov1"
     neighbor_counts.iloc[0:100, 1] = np.arange(100) + 1
-    neighbor_counts.iloc[0:50, 2:4] = np.random.randint(low=0, high=10, size=(50, 2))
-    neighbor_counts.iloc[50:100, 2:4] = np.random.randint(low=990, high=1000, size=(50, 2))
+    neighbor_counts.iloc[0:100, 2] = "cell_type"
+    neighbor_counts.iloc[0:50, 3:5] = np.random.randint(low=0, high=10, size=(50, 2))
+    neighbor_counts.iloc[50:100, 3:5] = np.random.randint(low=990, high=1000, size=(50, 2))
 
     neighbor_counts.iloc[100:200, 0] = "fov2"
     neighbor_counts.iloc[100:200, 1] = np.arange(100) + 1
-    neighbor_counts.iloc[100:150, 2:4] = np.random.randint(low=990, high=1000, size=(50, 2))
-    neighbor_counts.iloc[150:200, 2] = np.random.randint(low=0, high=10, size=50)
-    neighbor_counts.iloc[150:200, 3] = np.random.randint(low=990, high=1000, size=50)
+    neighbor_counts.iloc[100:200, 2] = "cell_type"
+    neighbor_counts.iloc[100:150, 3:5] = np.random.randint(low=990, high=1000, size=(50, 2))
+    neighbor_counts.iloc[150:200, 3] = np.random.randint(low=0, high=10, size=50)
+    neighbor_counts.iloc[150:200, 4] = np.random.randint(low=990, high=1000, size=50)
 
     return neighbor_counts
 
